@@ -16,4 +16,5 @@ nbands <- function(x)
 
 
 is.speclib <- function(x)
-  class(x) == "Speclib"
\ No newline at end of file
+  any(c(class(x) == "Speclib",
+        class(x) == "Specfeat"))
\ No newline at end of file
